# Obsplus Dataset: sulphur_peak

A 2017 southern Idaho (USA) earthquake sequence. 

# More info

This dataset was collected by the University of Utah Seismograph Stations (UUSS) as well a 
temporary network installed by UUSS and the United States Geological Survey. More info
can be found at the 
[sequence's webpage](https://quake.utah.edu/monitoring-research/sulphur-peak-earthquake).

This dataset only includes events available from USGS with minimum magnitudes >= 4.0
and stations within 0.5 degrees of the approximate cluster.


# References

Koper, K. D., Pankow, K. L., Pechmann, J. C., Hale, J. M., Burlacu, R., Yeck, W. L., ... & 
Shearer, P. M. (2018). Afterslip enhanced aftershock activity during the 2017 earthquake
sequence near Sulphur Peak, Idaho. Geophysical Research Letters, 45(11), 5352-5361.

Shokrgozar, A., & Mashal, M. (2019, April). The Mw 5.3 Sulphur Peak Earthquake in Soda
Springs, Idaho: Perspectives from Earthquake Engineering. In Structures Congress (pp. 306-320).
